@@ -70,12 +70,11 @@ class UrlRewriteTorrentleech(object):
             log.debug("Got the URL: %s" % entry['url'])
         if entry['url'].startswith('http://torrentleech.org/torrents/browse/index/query/'):
             # use search
-            try:
-                entry['url'] = self.search(entry)[0]['url']
-            except PluginWarning as e:
-                raise UrlRewritingError(e)
-        else:
-            entry['url'] = entry['url']
+            results = self.search(entry)
+            if not results:
+                raise UrlRewritingError("No search results found")
+            # TODO: Search doesn't enforce close match to title, be more picky
+            entry['url'] = results[0]['url']
 
     @internet(log)
     def search(self, entry, config=None):
@@ -98,61 +97,53 @@ class UrlRewriteTorrentleech(object):
             category = config['category']
         else:
             category = CATEGORIES.get(config.get('category', 'all'))
-        filter_url = '/categories/%d' % (category)
+        filter_url = '/categories/%d' % category
+        entries = set()
+        for search_string in entry.get('search_strings', [entry['title']]):
+            query = normalize_unicode(search_string)
+            # urllib.quote will crash if the unicode string has non ascii characters, so encode in utf-8 beforehand
+            url = ('http://torrentleech.org/torrents/browse/index/query/' +
+                   urllib.quote(query.encode('utf-8')) + filter_url)
+            log.debug('Using %s as torrentleech search url' % url)
 
-        query = normalize_unicode(entry['title'])
-        # urllib.quote will crash if the unicode string has non ascii characters, so encode in utf-8 beforehand
-        url = 'http://torrentleech.org/torrents/browse/index/query/' + urllib.quote(query.encode('utf-8')) + filter_url
-        log.debug('Using %s as torrentleech search url' % url)
+            page = requests.get(url, cookies=login.cookies).content
+            soup = get_soup(page)
 
-        page = requests.get(url, cookies=login.cookies).content
-        soup = get_soup(page)
+            for tr in soup.find_all("tr", ["even", "odd"]):
+                # within each even or odd row, find the torrent names
+                link = tr.find("a", attrs={'href': re.compile('/torrent/\d+')})
+                log.debug('link phase: %s' % link.contents[0])
+                entry = Entry()
+                # extracts the contents of the <a>titlename/<a> tag
+                entry['title'] = link.contents[0]
 
-        entries = []
-        for tr in soup.find_all("tr", ["even", "odd"]):
-            # within each even or odd row, find the torrent names
-            link = tr.find("a", attrs={'href': re.compile('/torrent/\d+')})
-            log.debug('link phase: %s' % link.contents[0])
-            entry = Entry()
-            # extracts the contents of the <a>titlename/<a> tag
-            entry['title'] = link.contents[0]
+                # find download link
+                torrent_url = tr.find("a", attrs={'href': re.compile('/download/\d+/.*')}).get('href')
+                # parse link and split along /download/12345 and /name.torrent
+                download_url = re.search('(/download/\d+)/(.+\.torrent)', torrent_url)
+                # change link to rss and splice in rss_key
+                torrent_url = 'http://torrentleech.org/rss' + download_url.group(1) + '/' + rss_key + '/' + download_url.group(2)
+                log.debug('RSS-ified download link: %s' % torrent_url)
+                entry['url'] = torrent_url
 
-            # find download link
-            torrent_url = tr.find("a", attrs={'href': re.compile('/download/\d+/.*')}).get('href')
-            # parse link and split along /download/12345 and /name.torrent
-            download_url = re.search('(/download/\d+)/(.+\.torrent)', torrent_url)
-            # change link to rss and splice in rss_key
-            torrent_url = 'http://torrentleech.org/rss' + download_url.group(1) + '/' + rss_key + '/' + download_url.group(2)
-            log.debug('RSS-ified download link: %s' % torrent_url)
-            entry['url'] = torrent_url
+                # us tr object for seeders/leechers
+                seeders, leechers = tr.find_all('td', ["seeders", "leechers"])
+                entry['torrent_seeds'] = int(seeders.contents[0])
+                entry['torrent_leeches'] = int(leechers.contents[0])
+                entry['search_sort'] = torrent_availability(entry['torrent_seeds'], entry['torrent_leeches'])
 
-            # us tr object for seeders/leechers
-            seeders, leechers = tr.find_all('td', ["seeders", "leechers"])
-            entry['torrent_seeds'] = int(seeders.contents[0])
-            entry['torrent_leeches'] = int(leechers.contents[0])
-            entry['search_sort'] = torrent_availability(entry['torrent_seeds'], entry['torrent_leeches'])
+                # use tr object for size
+                size = tr.find("td", text=re.compile('([\.\d]+) ([GMK])B')).contents[0]
+                size = re.search('([\.\d]+) ([GMK])B', size)
+                if size:
+                    if size.group(2) == 'G':
+                        entry['content_size'] = int(float(size.group(1)) * 1000 ** 3 / 1024 ** 2)
+                    elif size.group(2) == 'M':
+                        entry['content_size'] = int(float(size.group(1)) * 1000 ** 2 / 1024 ** 2)
+                    else:
+                        entry['content_size'] = int(float(size.group(1)) * 1000 / 1024 ** 2)
+                entries.add(entry)
 
-            # use tr object for size
-            size = tr.find("td", text=re.compile('([\.\d]+) ([GMK])B')).contents[0]
-            size = re.search('([\.\d]+) ([GMK])B', size)
-            if size:
-                if size.group(2) == 'G':
-                    entry['content_size'] = int(float(size.group(1)) * 1000 ** 3 / 1024 ** 2)
-                elif size.group(2) == 'M':
-                    entry['content_size'] = int(float(size.group(1)) * 1000 ** 2 / 1024 ** 2)
-                else:
-                    entry['content_size'] = int(float(size.group(1)) * 1000 / 1024 ** 2)
-            entries.append(entry)
-
-        if not entries:
-            dashindex = query.rfind('-')
-            if dashindex != -1:
-                return self.search(query[:dashindex])
-            else:
-                raise PluginWarning('No close matches for %s' % query, log, log_once=True)
-
-        entries.sort(reverse=True, key=lambda x: x.get('search_sort'))
-
-        return entries
+        return sorted(entries, reverse=True, key=lambda x: x.get('search_sort'))
 
 register_plugin(UrlRewriteTorrentleech, 'torrentleech', groups=['urlrewriter', 'search'])
